import asyncio

from fastapi import APIRouter, HTTPException, status, Depends
from database import db_connection as db

from database.models.nodes import Node
from onvif_proxy.hot_cams import HotCams
from database.repositories.nodes import NodeRepository
from database.schemas.nodes import NodeFull

node_router = APIRouter()

current_node: Node | None = None
hot_cams: HotCams = HotCams()


@node_router.post("/set/{node_id}", response_model=NodeFull)
async def set_node_id(
        node_id: int,
        node_repo: NodeRepository = Depends(db.get_repository(NodeRepository))
):
    global current_node
    global hot_cams
    node = await node_repo.get(node_id)
    if node is None:
        raise HTTPException(
            status_code=status.HTTP_404_NOT_FOUND
        )
    current_node = node

    # Warm up cams
    del hot_cams
    hot_cams = HotCams()
    asyncio.create_task(
        hot_cams.connect_cams_list(
            [int(cam.id) for cam in await node_repo.get_node_cams(current_node)]
        )
    )
    return current_node


@node_router.get("", response_model=NodeFull)
async def get_node():
    global current_node
    if current_node is None:
        raise HTTPException(
            status_code=status.HTTP_418_IM_A_TEAPOT,
            detail="Node ID not set yet."
        )
    return current_node
