from sqlalchemy import Column, Integer, String, ForeignKey,\
    Index, UniqueConstraint
from .base import Base


class Cam(Base):
    __tablename__ = 'cams'

    id: Column = Column(Integer, primary_key=True)  # Will make SERIAL
    name: Column = Column(String, unique=True, nullable=False)
    host: Column = Column(String, nullable=False)
    port: Column = Column(Integer, unique=False, nullable=False)
    username: Column = Column(String, nullable=False)
    password: Column = Column(String, nullable=False)

    __table_args__ = (
        Index('cams_host_index', 'host', unique=False),
        Index('cams_host_port_index', 'host', 'port', unique=True),
    )


class Group(Base):
    __tablename__ = 'cam_groups'

    id: Column = Column(Integer, primary_key=True)  # Will make SERIAL
    name: Column = Column(String, unique=True, nullable=False)


class CamInGroup(Base):
    __tablename__ = 'cam_in_group'

    cam_id: Column = Column(Integer, ForeignKey('cams.id'), primary_key=True)
    group_id: Column = Column(Integer, ForeignKey('cam_groups.id'), primary_key=True)
    node_id: Column = Column(Integer, ForeignKey('nodes.id'), unique=False, nullable=False)

    __table_args__ = (
        Index('cig_cam_id_index', 'cam_id', unique=False),
        Index('cig_group_id_index', 'group_id', unique=False),
        UniqueConstraint('group_id', 'node_id', name='uc_group_node'),
    )


class UserInGroup(Base):
    __tablename__ = 'user_in_group'

    user_id: Column = Column(Integer, ForeignKey('users.id'), primary_key=True)
    group_id: Column = Column(Integer, ForeignKey('cam_groups.id'), primary_key=True)

    __table_args__ = (
        Index('uig_user_id_index', 'user_id', unique=False),
        Index('uig_group_id_index', 'group_id', unique=False),
    )
